@@ -23,6 +23,7 @@ from mistralclient.api.v2 import action_executions
 from mistralclient.api.v2 import actions
 from mistralclient.api.v2 import cron_triggers
 from mistralclient.api.v2 import environments
+from mistralclient.api.v2 import event_triggers
 from mistralclient.api.v2 import executions
 from mistralclient.api.v2 import members
 from mistralclient.api.v2 import services
@@ -38,6 +39,7 @@ _DEFAULT_MISTRAL_URL = "http://localhost:8989/v2"
 
 
 class Client(object):
+
     def __init__(self, auth_type='keystone', **kwargs):
         # We get the session at this point, as some instances of session
         # objects might have mutexes that can't be deep-copied.
@@ -51,12 +53,16 @@ class Client(object):
 
         # If auth url was provided then we perform an authentication, otherwise
         # just ignore this step
-        if req.get('auth_url'):
+        if req.get('auth_url') or req.get('target_auth_url'):
             auth_handler = auth.get_auth_handler(auth_type)
             auth_response = auth_handler.authenticate(req, session=session)
         else:
             auth_response = {}
 
+        # If the session was None and we're using keystone auth, it will be
+        # created by the auth_handler.
+        session = auth_response.pop('session', None)
+
         req.update(auth_response)
 
         mistral_url = auth_response.get('mistral_url') or mistral_url
@@ -77,6 +83,7 @@ class Client(object):
         self.actions = actions.ActionManager(http_client)
         self.workflows = workflows.WorkflowManager(http_client)
         self.cron_triggers = cron_triggers.CronTriggerManager(http_client)
+        self.event_triggers = event_triggers.EventTriggerManager(http_client)
         self.environments = environments.EnvironmentManager(http_client)
         self.action_executions = action_executions.ActionExecutionManager(
             http_client)
