@@ -31,8 +31,8 @@ class Execution(base.Resource):
 class ExecutionManager(base.ResourceManager):
     resource_class = Execution
 
-    def create(self, workflow_identifier, workflow_input=None, description='',
-               **params):
+    def create(self, workflow_identifier, namespace='', workflow_input=None,
+               description='', **params):
         self._ensure_not_empty(workflow_identifier=workflow_identifier)
 
         data = {
@@ -44,6 +44,9 @@ class ExecutionManager(base.ResourceManager):
         else:
             data.update({'workflow_name': workflow_identifier})
 
+        if namespace:
+            data.update({'workflow_namespace': namespace})
+
         if workflow_input:
             if isinstance(workflow_input, six.string_types):
                 data.update({'input': workflow_input})
@@ -79,7 +82,7 @@ class ExecutionManager(base.ResourceManager):
         if marker:
             qparams['marker'] = marker
 
-        if limit:
+        if limit and limit > 0:
             qparams['limit'] = limit
 
         if sort_keys:
